"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addImportToCode = exports.stylePathHandler = exports.parseImportModule = exports.codeIncludesLibName = exports.optionsCheck = void 0;
const parser_1 = require("@babel/parser");
const generator_1 = __importDefault(require("@babel/generator"));
// 驼峰转横线
const camel2DashName = (name) => name[0].toLowerCase() + name.substring(1).replace(/([A-Z])/g, ($1) => `-${$1.toLowerCase()}`);
const isString = (str) => (typeof str === 'string');
const isArray = (list) => Array.isArray(list);
const optionsCheck = (libs) => {
    if (isArray(libs) && libs?.length)
        return true;
    console.error('libs is required, please check your options!');
    return false;
};
exports.optionsCheck = optionsCheck;
const codeIncludesLibName = (code, libs) => !libs.every(({ libName }) => !new RegExp(`('${libName}')|("${libName}")`).test(code));
exports.codeIncludesLibName = codeIncludesLibName;
function parseImportModule(code, libs, command) {
    const ast = (0, parser_1.parse)(code, {
        sourceType: 'module',
        plugins: [
            'jsx'
        ]
    });
    const astBody = ast.program.body;
    const importMaps = {};
    const toBeRemoveIndex = [];
    let newImportStatement = '';
    if (isArray(astBody)) {
        astBody.forEach((astNode, index) => {
            const libName = astNode?.source?.value || '';
            const matchLib = libs.find(lib => lib.libName === libName);
            if (astNode.type === 'ImportDeclaration' && matchLib) {
                const { camel2Dash = true } = matchLib;
                astNode.specifiers.forEach((item) => {
                    const name = item?.imported.name;
                    const localName = item?.local.name;
                    if (!name)
                        return;
                    const { libDir = 'es' } = matchLib;
                    if (command === 'build') {
                        const finalName = camel2Dash ? camel2DashName(name) : name;
                        newImportStatement += `import ${localName} from '${libName}/${libDir}/${finalName}';`;
                        toBeRemoveIndex.push(index);
                    }
                    if (importMaps[libName]) {
                        importMaps[libName].push(name);
                    }
                    else {
                        importMaps[libName] = [name];
                    }
                });
            }
        });
    }
    ast.program.body = astBody.filter((item, index) => !toBeRemoveIndex.includes(index));
    const codeRemoveOriginImport = `${newImportStatement}; ${(0, generator_1.default)(ast).code}`;
    return { importMaps, codeRemoveOriginImport };
}
exports.parseImportModule = parseImportModule;
const stylePathHandler = (stylePath) => {
    let str = '';
    if (isString(stylePath) && stylePath) {
        str += `import '${stylePath}';`;
    }
    else if (Array.isArray(stylePath)) {
        stylePath.forEach((item) => {
            str += `import '${item}';`;
        });
    }
    return str;
};
exports.stylePathHandler = stylePathHandler;
const addImportToCode = (code, libs, command = 'serve') => {
    const { importMaps, codeRemoveOriginImport } = parseImportModule(code, libs, command);
    let importStr = '';
    libs.forEach(({ libName, style = 'css', base = false, libDir = 'es', camel2Dash = true }) => {
        if (importMaps[libName]) {
            importMaps[libName].forEach(item => {
                if (camel2Dash)
                    item = camel2DashName(item);
                const basePath = (base && typeof base === 'string') ? base : `import '${libName}/${libDir}/base.css';`;
                let stylePath;
                if (typeof style === 'function') {
                    stylePath = style(item);
                }
                else if (style === 'css' || style === true) {
                    stylePath = `${libName}/${libDir}/${item}/style.css`;
                }
                else if (style === false) {
                    stylePath = '';
                }
                else {
                    stylePath = `${libName}/${libDir}/${item}/style.${style}`;
                }
                const styleImportString = basePath + (0, exports.stylePathHandler)(stylePath);
                importStr += styleImportString;
            });
        }
    });
    return `${importStr}${codeRemoveOriginImport}`;
};
exports.addImportToCode = addImportToCode;
